Untitled Document

| Performance Summary for Gitmo Suntan |  | Description: GS is a commercially available daily signal purchased from General Systems, Inc. The signal varies from 0 to 100 according to the likelihood that the management of the corresponding equity resides at Guantanomo Bay. Prepared By: Tucker Balch (tucker@cc.gatech.edu) |

| Performance Metrics† | 2005- |  | 2008- |  | 2009- |  | Last 6 mos |  |  |
| Annualized Return | 21.0 | % | 15 | % | 15 | % | 15 | % |  |
| Winning Days | 75.0 | % | 60 | % | 60 | % | 60 | % |  |
| Monthly Max Drawdown | 10.0 | % | 10 | % | 5 | % | 5 | % |  |
| Expected Shortfall | 15.0 | % | 20 | % | 20 | % | 20 | % |  |
| Daily Sharpe Ratio | 2.3 | ±0.1 | 1.8 | ±0.1 | 1.8 | ±0.1 | 1.8 | ±0.1 |  |
| Monthly Sharpe Ratio | 2.5 | ±0.1 | 1.9 | ±0.1 | 1.9 | ±0.1 | 1.9 | ±0.1 |  |

| Monthly Returns | Jan | Feb | Mar | Apr | May | Jun | Jul | Aug | Sep | Oct | Nov | Dec |
| 2005 | 1.5% | -1.0% | 3.0% | 0.5% | 1.5% | 3.0% | 1.5% | 3.0% | 3.0% | -1.0% | 3.0% | 1.5% |
| 2006 | 1.5% | -1.0% | 0.5% | 0.5% | -0.2% | 3.0% | -1.0% | -1.0% | 3.0% | 3.0% | 3.0% | 3.0% |
| 2007 | 1.5% | 3.0% | 1.5% | 3.0% | 3.0% | 0.5% | 3.0% | 3.0% | 0.5% | 1.5% | 1.5% | 0.5% |
| 2008 | 3.0% | 0.5% | 3.0% | -1.0% | 3.0% | 3.0% | 1.5% | 3.0% | 3.0% | -1.0% | 3.0% | 3.0% |
| 2009 | 1.5% | -1.0% | -1.0% | 3.0% | 1.5% | 3.0% | 3.0% | 1.5% | 0.5% | 3.0% | -1.0% | -1.0% |

| Correlation |  |  | Performance versus Benchmarks |
| S&P 500 | .05 | ±0.1 |  |
| DJIA | .10 | ±0.1 |
| Barclay Long/Short HFI | .03 | ±0.1 |
| Barclay Market Neutral HFI | .02 | ±0.1 |
| HFRI Absolute Return | .09 | ±0.1 |
| Risk-free Return Reference | 90-day T-bills |

| †Annualized Return is the difference between the value of holdings at the end of the year versus the start of the year as a percentage of the value at the start of the year. When a full year of data is not available, a projected estimate is provided. Winning Days is the percentage of days that returns exceeded a risk-free rate of return (90 day T-bills). Monthly Max Drawdown is the mean of maximum peak-to-trough differences measured monthly. Expected Shortfall is the mean return of the 95th percentile of worst trading days. Daily Sharpe Ratio is the annualized Sharpe ratio calculated using daily returns. Monthly Sharpe Ratio is the Sharpe Ratio calculated using montly returns. Disclaimer: The information in this report does not constitute the provision of investment advice. In addition, the information in this report does not convey an offer of any type and is not intended to be, and should not be construed as, an offer to sell, or the solicitation of an offer to buy, any securities or other financial products. |